import base64
from pathlib import Path

class GeneratedImages:
    def __init__(self, images: dict):
        self.images = images
    
    def save_images(self, path: str=None):
        '''
        Saves the generated images to the given path.
        Defaults to cwd/generated
        '''
        path = (Path.cwd() / 'generated') if not path else Path(path)
        path.mkdir(parents=True, exist_ok=True)
        for i in enumerate(self.images):
            with open(path / f'image-{i[0]+1}.png', 'wb') as f:
                f.write(base64.decodebytes(i[1].encode('utf-8')))


from __future__ import annotations
import requests
from craiyon.templates import GeneratedImages

class Craiyon:
    '''
    Instantiates a Craiyon session, allows user to generate images from text tokens.
    The model takes some time to generate the images (roughly around 2 minutes).
    The code is itself blocking, so either use a thread or wait for me to write an async version.
    So be patient, and don't abuse the api, as I am not the one hosting the model, craiyon itself is.
    '''
    def __init__(self) -> None:
        self.BASE_URL = "https://backend.craiyon.com"
        self.session = requests.Session()

    def generate(self, tokens: str) -> GeneratedImages:
        url = self.BASE_URL + "/generate"
        resp = self.session.post(url, json={'prompt': tokens})
        return GeneratedImages(resp.json()['images'])


from setuptools import setup

with open("README.md", "r", encoding="utf-8") as fh:
    readme = fh.read()

setup(name='craiyon.py',
      version='0.1.0',
      description='API Wrapper for craiyon.com (DAL-E-MINI). Generate awesome images from text tokens.',
      long_description=readme,
      long_description_content_type="text/markdown",
      url='https://github.com/FireHead90544/craiyon.py',
      project_urls={
        "Issue tracker": "https://github.com/FireHead90544/craiyon.py/issues",
      },
      author='Rudransh Joshi',
      author_email='rudranshjoshi1806@gmail.com',
      platforms='any',
      license='Apache License 2.0',
      packages=['craiyon'],
      zip_safe=False,
      install_requires=["requests"])